pub fn decode_with(
bytes: &[u8],
trust: TrustLevel,
) -> Result<Chunk, FormatError>Expand description
Decode with an explicit trust level. Trusted decode is for host-packed modules that may embed authority tags in the constant pool.
pub fn decode_with(
bytes: &[u8],
trust: TrustLevel,
) -> Result<Chunk, FormatError>Decode with an explicit trust level. Trusted decode is for host-packed modules that may embed authority tags in the constant pool.